@@ -3,6 +3,9 @@ import numpy as np
 import matplotlib.pyplot as plt
 import os
 
+label = os.path.splitext(os.path.basename(__file__))[0]
+outdir = os.path.join("PyFstat_example_data", label)
+
 F0 = 30.0
 F1 = -1e-10
 F2 = 0
@@ -17,9 +20,6 @@ tend = tstart + duration
 tref = 0.5 * (tstart + tend)
 
 depth = 40
-label = os.path.splitext(os.path.basename(__file__))[0]
-outdir = os.path.join("example_data", label)
-
 h0 = sqrtSX / depth
 
 data = pyfstat.Writer(
@@ -99,4 +99,5 @@ if hasattr(mcmc, "walkers_fig") and hasattr(mcmc, "walkers_axes"):
         os.path.join(mcmc.outdir, mcmc.label + "_walkers.png"), dpi=400
     )
     mcmc.plot_corner(add_prior=True)
+    mcmc.plot_prior_posterior()
     mcmc.print_summary()
